###############################################################################
###############################################################################
##                          ayuda.tcl
##
## Incluye los procedimientos necesarios para los comandos que se encuentran
## en el men de ayuda
##
## (c) 1999 Andrs Garca Garca.
## Distribuible segn los trminos de la licencia GNU
###############################################################################
###############################################################################

namespace eval Ayuda {

###############################################################################
# CrearVentana
#    Creates a window to show the content of a file text.
#
# Paremeters:
#    titulo: title for the window.
#    fichero: file to show.
#    log: '1' if we are going to show the error log, defaults to '0'
###############################################################################
proc CrearVentana {titulo fichero {log 0} } {
    global coord
    global labelButtons labelTitles labelMessages

    if [catch {open $fichero r} handle] {
        tk_messageBox -title $labelTitles(error) -icon error \
            -message [concat $labelMessages(notFound) \n $fichero]
        return
    }

    fijar_coordenadas

    set ventana [toplevel .ventana]
    wm title $ventana $titulo
    wm resizable $ventana 0 0
    wm geometry $ventana +[expr $coord(x)+100]+[expr $coord(y)+50]

    set marcoExt [frame $ventana.marcoext]
    set marcoInt [frame $marcoExt.marcoint]
    set marcoTex [frame $marcoInt.marcotex -bd 2 -relief sunken]
    set botones  [frame $ventana.botones]

    set texto [text $marcoTex.texto -wrap none -bg white \
            -yscrollcommand [list $marcoTex.yscroll set] \
            -xscrollcommand [list $marcoInt.xscroll set] ]

    set barray [scrollbar $marcoTex.yscroll -orient vertical \
            -command [list $texto yview] ]
    set barrax [scrollbar $marcoInt.xscroll -orient horizontal \
            -command [list $texto xview] ]

    set aceptar [button $botones.aceptar -text $labelButtons(ok) -width 8 \
            -command "destroy \"$ventana\""]
    set clear   [button $botones.clear   -text $labelButtons(clear) -width 8 \
            -command "
                ::Herramientas::EraseErrorLog
                destroy $ventana " ]

    pack $marcoExt -ipadx 10 -ipady 5
    pack $marcoInt -side bottom
    if {$log==0} {
        pack $marcoTex -side bottom
    } else {
        pack $barrax $marcoTex -side bottom -fill x
    }
    pack $barray $texto -side right -fill y
    pack $botones
    pack $aceptar -pady 5 -padx 2 -side right
    if {$log==1} {
        pack $clear -pady 5 -padx 2
    }
    for {} {![eof $handle]} {} {
        set linea [gets $handle]
        $texto insert insert $linea\n
    }
    close $handle
    $texto configure -state disabled

    bind $aceptar <Return> "\"$aceptar\" invoke"
    bind $clear   <Return> "\"$clear\" invoke"

    grab $ventana
    tkwait window $ventana

    return
}

###############################################################################
# Manual
#   Shows Getleft manual.
###############################################################################
proc Manual {} {
    global dirGetleft labelTitles

    CrearVentana $labelTitles(manual) [file join "$dirGetleft(doc)" Readme.txt]

    return
}

###############################################################################
# Changes
#   Shows the 'Changes' log
###############################################################################
proc Changes {} {
    global dirGetleft labelTitles

    CrearVentana $labelTitles(changes) [file join "$dirGetleft(doc)" Changes.txt]

    return
}

###############################################################################
# Licencia
#   Shows the GPL licence.
###############################################################################
proc Licencia {} {
    global dirGetleft labelTitles

    CrearVentana  $labelTitles(license) \
            [file join "$dirGetleft(doc)" license.txt]

    return
}

###############################################################################
# AcercaDe
#    Shows some info about the program.
###############################################################################
proc AcercaDe {} {
    global dirGetleft coord
    global labelButtons labelTitles

    set ven [toplevel .acercade]
    wm title $ven $labelTitles(about)
    wm resizable $ven 0 0

    fijar_coordenadas
    wm geometry $ven +[expr $coord(x)+180]+[expr $coord(y)+110]

    set interno    [frame $ven.interno -bd 2 -relief sunken]
    set internoLft [frame $interno.left]
    set internoCnt [frame $interno.center]
    set internoRgt [frame $interno.right]

    set tclLogo [image create photo -file "$dirGetleft(images)/pwrdLogo150.gif"]
    set tclIma  [label $internoLft.tcl -image $tclLogo]

    set text    [image create photo -file "$dirGetleft(images)/about.gif"]
    set textIma [label $internoCnt.texto -image $text]

    set curl    [image create photo -file "$dirGetleft(images)/curl.gif"]
    set curlIma [label $internoRgt.curl  -image $curl]

    button $ven.aceptar -text $labelButtons(ok) -command "destroy $ven"

    pack $interno
    pack $internoLft $internoCnt $internoRgt -side left
    pack $tclIma
    pack $textIma
    pack $curlIma

    pack $ven.aceptar -pady 2

    grab $ven

    return
}
}